################## MANDELBROTOVA a JULIOVA   MNOZINA ##################
import numpy as np               # import balicku
import matplotlib.pyplot as plt  # import balicku

# Nastavte hodnotu parametru c_J a spust program
##################  Volitelne parametry ##################
c_J          = -0.8 + 0.35j      # parametr c Juliovy mnoziny

################## Pomocna nastaveni ##################
x_min, x_max = -2, 2           # zobrazeny rozsah hodnot v realne ose
y_min, y_max = -1.5, 1.5       # zobrazeny rozsah hodnot v imaginarni ose 
max_it       = 150             # maximalni pocet iteraci
rozl_x       = 1000            # pocer bodu na realnou osu
rozl_y       = 1000            # pocet bodu na imaginarni osu
m            = 4               # parametr funkce
barva        = "RdPu"          # nastaveni barevneho spektra ("hsv", "cool" aj. ...)
zobr_oblast  = [x_min, x_max, y_min, y_max]  # zobrazovana oblast

####### Definice funkce pocitajici hodnoty Mandelbrotovy mnoziny ###############
def Mandelbrot(rozl_y, rozl_x, x_min, x_max, y_min, y_max, m, max_it):
  MM = np.full([rozl_y, rozl_x],0)
  X = np.linspace(x_min, x_max, num = rozl_x)
  Y = np.linspace(y_min, y_max, num = rozl_y)
  for y_index, y in enumerate(Y):
    for x_index, x in enumerate(X):
      i = 0
      c = complex (x, y)
      z = 0
      while (abs(z)) <= m and i < max_it:
        z = z**2 + c        # vypocet hodnoty Mandelbrotovy mnoziny
        i += 1
      MM[rozl_y-1-y_index, x_index] = 255-i # prirazeni iterace
  return MM  
  
####### Definice funkce pocitajici hodnoty Juliovzy mnoziny ###############  
def Julia(c,rozl_y, rozl_x, x_min, x_max, y_min, y_max, m, max_it):
  JM = np.full([rozl_y, rozl_x],0)
  X = np.linspace(x_min, x_max, num = rozl_x)
  Y = np.linspace(y_min, y_max, num = rozl_y)
  for y_index, y in enumerate(Y):
    for x_index, x in enumerate(X):
      i = 0
      z = complex (x, y)
      while (abs(z)) < m and i < max_it:
        z = z**2 + c       # vypocet hodnoty Juliovy mnoziny
        i += 1
      JM[rozl_y-1-y_index, x_index] = 255-i # prirazeni iterace
  return JM
                                                                                
################## Vykresleni mnozin ##################
Mandelbrot_data = Mandelbrot(rozl_y, rozl_x, x_min, x_max, y_min, y_max, m, max_it)
Julia_data = Julia(c_J, rozl_y, rozl_x, x_min, x_max, y_min, y_max, m, max_it)

plt.figure(figsize=(15, 5))    # definice zakl. obrazku

plt.subplot(1, 2, 1)           # subplot pro Mandelbrotovu mnozinu
plt.imshow(Mandelbrot_data , cmap = barva, extent = zobr_oblast, origin='lower')
plt.scatter(c_J.real,c_J.imag, s = 90, c = 'y', marker = 'o')  # vykresleni c_J
plt.axis([x_min, x_max, y_min, y_max])   
plt.axis('off')                # vypnuti/zapnuti os
plt.grid('off')                # vypnuti/zapnuti mrizky
                           
plt.subplot(1, 2, 2)           # subplot pro Mandelbrotovu mnozinu
plt.imshow(Julia_data , cmap = barva, extent = zobr_oblast)
plt.axis([x_min, x_max, y_min, y_max]) 
plt.axis('off')                # vypnuti/zapnuti os
plt.grid('off')                # vypnuti/zapnuti mrizky
      
plt.tight_layout(pad=0)
plt.show()
